@@ -3,7 +3,7 @@ using MLStyle: @match, @switch
 import LinearAlgebra
 import TyPython.C
 import TyPython.Utils: capture_out, unroll_do!
-export get_py_builtin, py_throw, WITH_GIL, GILNoRaise
+export get_numpy, get_py_builtin, py_throw, WITH_GIL, GILNoRaise
 export py_cast, py_coerce
 export Py
 
